/*
 * StaticGraphGenerator.cpp
 *
 *  Created on: 09.04.2013
 *      Author: cls
 */

#include <networkit/generators/StaticGraphGenerator.hpp>

namespace NetworKit {

} /* namespace NetworKit */
